"use strict";
var testHelper_1 = require('./testHelper');
describe('component-class-suffix', function () {
    describe('invalid component class suffix', function () {
        it('should fail when component class is with the wrong suffix', function () {
            var source = "\n              @Component({\n                selector: 'sg-foo-bar'\n              })\n              class Test {}";
            testHelper_1.assertFailure('component-class-suffix', source, {
                message: 'The name of the class Test should end with the suffix Component',
                startPosition: {
                    line: 4,
                    character: 20
                },
                endPosition: {
                    line: 4,
                    character: 24
                }
            });
        });
    });
    describe('valid component class name', function () {
        it('should succeed when the component class name ends with Component', function () {
            var source = "\n            @Component({\n                selector: 'sg-foo-bar'\n            })\n            class TestComponent {}";
            testHelper_1.assertSuccess('component-class-suffix', source);
        });
    });
    describe('valid directive class', function () {
        it('should succeed when is used @Directive decorator', function () {
            var source = "\n            @Directive({\n                selector: '[myHighlight]'\n            })\n            class TestDirective {}";
            testHelper_1.assertSuccess('component-class-suffix', source);
        });
    });
    describe('valid pipe class', function () {
        it('should succeed when is used @Pipe decorator', function () {
            var source = "\n            @Pipe({\n                selector: 'sg-test-pipe'\n            })\n            class TestPipe {}";
            testHelper_1.assertSuccess('component-class-suffix', source);
        });
    });
    describe('valid service class', function () {
        it('should succeed when is used @Injectable decorator', function () {
            var source = "\n            @Injectable()\n            class TestService {}";
            testHelper_1.assertSuccess('component-class-suffix', source);
        });
    });
    describe('valid empty class', function () {
        it('should succeed when the class is empty', function () {
            var source = "\n            class TestEmpty {}";
            testHelper_1.assertSuccess('component-class-suffix', source);
        });
    });
});
