"use strict";
var testHelper_1 = require('./testHelper');
describe('no-forward-ref', function () {
    describe('invalid function call', function () {
        it('should fail when we are calling forwardRef in constructor', function () {
            var source = "\n      class Test {\n        constructor(@Inject(forwardRef(()=>NameService)) nameService) {}\n      }\n      class NameService {}";
            testHelper_1.assertFailure('no-forward-ref', source, {
                message: 'Avoid using forwardRef in class "Test"',
                startPosition: {
                    line: 2,
                    character: 28
                },
                endPosition: {
                    line: 2,
                    character: 55
                }
            });
        });
        it('should fail when we are calling forwardRef in Component directives array', function () {
            var source = "\n      @Component({\n        directives: [forwardRef(()=>NameService)]\n      })\n      class Test {}\n      class NameService {}";
            testHelper_1.assertFailure('no-forward-ref', source, {
                message: 'Avoid using forwardRef in class "Test"',
                startPosition: {
                    line: 2,
                    character: 21
                },
                endPosition: {
                    line: 2,
                    character: 48
                }
            });
        });
    });
    describe('valid function call', function () {
        it('should succeed, when we are not calling forwardRef', function () {
            var source = "\n      class Test {\n        constructor() {\n          this.test();\n        }\n        test(){\n        }\n      }";
            testHelper_1.assertSuccess('no-forward-ref', source);
        });
    });
});
