"use strict";
var testHelper_1 = require('./testHelper');
describe('pipe-naming', function () {
    describe('invalid pipe name', function () {
        it('should fail when Pipe is named camelCase with prefix ng', function () {
            var source = "\n                      @Pipe({\n                        name: 'foo-bar'\n                      })\n                      class Test {}";
            testHelper_1.assertFailure('pipe-naming', source, {
                message: 'The name of the Pipe decorator of class Test should be named camelCase with prefix ng, however its value is "foo-bar".',
                startPosition: {
                    line: 2,
                    character: 24
                },
                endPosition: {
                    line: 2,
                    character: 39
                }
            }, ['camelCase', 'ng']);
        });
    });
    describe('invalid pipe name', function () {
        it('should fail when Pipe is named camelCase without prefix', function () {
            var source = "\n                      @Pipe({\n                        name: 'foo-bar'\n                      })\n                      class Test {}";
            testHelper_1.assertFailure('pipe-naming', source, {
                message: 'The name of the Pipe decorator of class Test should be named camelCase, however its value is "foo-bar".',
                startPosition: {
                    line: 2,
                    character: 24
                },
                endPosition: {
                    line: 2,
                    character: 39
                }
            }, 'camelCase');
        });
    });
    describe('valid pipe name', function () {
        it('should succeed when set valid name with prefix ng in @Pipe', function () {
            var source = "\n                    @Pipe({\n                      name: 'ngBarFoo'\n                    })\n                    class Test {}";
            testHelper_1.assertSuccess('pipe-naming', source, ['camelCase', 'ng']);
        });
    });
    describe('valid pipe name', function () {
        it('should succeed when set valid name in @Pipe', function () {
            var source = "\n                    @Pipe({\n                      name: 'barFoo'\n                    })\n                    class Test {}";
            testHelper_1.assertSuccess('pipe-naming', source, ['camelCase']);
        });
    });
    describe('valid empty class', function () {
        it('should succeed when the class is not a Pipe', function () {
            var source = "\n                    class Test {}";
            testHelper_1.assertSuccess('pipe-naming', source, ['camelCase']);
        });
    });
});
