"use strict";
var testHelper_1 = require('./testHelper');
describe('pipe-transform-interface', function () {
    describe('invalid declaration of pipe', function () {
        it("should fail, when a Pipe is declared without implementing the PipeTransform interface", function () {
            var source = "\n                        @Pipe({name: 'fetch'})\n                        export class NewPipe{\n                          transform(url:string):any {\n                          }\n                        }";
            testHelper_1.assertFailure('pipe-transform-interface', source, {
                message: 'The NewPipe class has the Pipe decorator, so it should implement the PipeTransform interface',
                startPosition: {
                    line: 1,
                    character: 24
                },
                endPosition: {
                    line: 5,
                    character: 25
                }
            });
        });
    });
    describe('valid use of Pipe with the implementation of the PipeTransform interface', function () {
        it("should succeed when Pipe is declared properly", function () {
            var source = "\n                    @Pipe({name: 'fetch'})\n                    export class NewPipe  implements PipeTransform{\n                      transform(url:string):any {\n                      }\n                    }";
            testHelper_1.assertSuccess('pipe-transform-interface', source);
        });
    });
    describe('valid use of empty class', function () {
        it("should succeed, when Pipe is not used", function () {
            var source = "class App{}";
            testHelper_1.assertSuccess('pipe-transform-interface', source);
        });
    });
});
