"use strict";
var testHelper_1 = require('./testHelper');
describe('use-life-cycle-interface', function () {
    describe('invalid declaration of life hook', function () {
        it("should fail, when a life cycle hook is used without implementing it's interface", function () {
            var source = "\n            class App {\n                ngOnInit(){\n                }\n            }";
            testHelper_1.assertFailure('use-life-cycle-interface', source, {
                message: 'In class App the method ngOnInit is a life cycle hook and should implement the OnInit interface',
                startPosition: {
                    line: 1,
                    character: 12
                },
                endPosition: {
                    line: 4,
                    character: 13
                }
            });
        });
    });
    describe('invalid declaration of life hooks', function () {
        it("should fail, when life cycle hooks are used without implementing their interfaces", function () {
            var source = "\n            class App {\n                ngOnInit(){\n                }\n                ngOnDestroy(){\n                }\n            }";
            testHelper_1.assertFailure('use-life-cycle-interface', source, {
                message: 'In class App the methods - ngOnInit, ngOnDestroy are life cycle hooks and ' +
                    'should implement the interfaces: OnInit, OnDestroy',
                startPosition: {
                    line: 1,
                    character: 12
                },
                endPosition: {
                    line: 6,
                    character: 13
                }
            });
        });
    });
    describe('invalid declaration of life hooks', function () {
        it("should fail, when some of the life cycle hooks are used without implementing their interfaces", function () {
            var source = "\n            class App extends Component implements OnInit{\n                ngOnInit(){\n                }\n                ngOnDestroy(){\n                }\n            }";
            testHelper_1.assertFailure('use-life-cycle-interface', source, {
                message: 'In class App the method ngOnDestroy is a life cycle hook and should implement the OnDestroy interface',
                startPosition: {
                    line: 1,
                    character: 12
                },
                endPosition: {
                    line: 6,
                    character: 13
                }
            });
        });
    });
    describe('valid declaration of life hook', function () {
        it("should succeed, when life cycle hook is used with it's corresponding interface", function () {
            var source = "\n            class App implements OnInit {\n                ngOnInit(){\n                }\n            }";
            testHelper_1.assertSuccess('use-life-cycle-interface', source);
        });
    });
    describe('valid declaration of life hooks', function () {
        it("should succeed, when life cycle hooks are used with their corresponding interfaces", function () {
            var source = "\n            class App extends Component implements OnInit,OnDestroy  {\n                ngOnInit(){\n                }\n\n                private ngOnChanges:string=\"\";\n\n                ngOnDestroy(){\n                }\n\n                ngOnSmth{\n                }\n            }";
            testHelper_1.assertSuccess('use-life-cycle-interface', source);
        });
    });
    describe('valid use of class without interfaces and life cycle hooks', function () {
        it("should succeed when life cycle hooks are not used", function () {
            var source = "\n            class App{}";
            testHelper_1.assertSuccess('use-life-cycle-interface', source);
        });
    });
});
